# Run the server

Set the environment variable `ALPHAVANTAGE_API_KEY` to your Alphavantage API key.

```bash
uv --directory /Users/medusa/code/alphavantage run alphavantage
```

# Versioning

```bash
bumpversion patch
```




